#ifndef _LogManager_H__
#define _LogManager_H__

#include <vector>
#include <fstream>
#include <iostream>

#include "Containers.h"


namespace GtpVisibilityPreprocessor {


/** Log manager controlling the debug output.
	This class defines the pattern of singleton to assure that
	there is always only one log manager.
*/
class LogManager 
{
public:

	/** Returns the resource manager as a singleton.
	*/
	static LogManager *GetSingleton();

	static void DelSingleton();

protected:

	/** Default constructor. The constructor is protected
		to have control over instantiation using the 
		singleton pattern.
	*/
	LogManager();

	~LogManager() {}

	void LogMessage(const std::string &str);

protected:
	std::ofstream mOutStream;

private:
	static LogManager *sLogManager;
};


}

#endif
